%------------------------------------------------------------
%               increaseaddedres.m
%               Hege Eskild
%               Spring 2014
%
% This read function reads several input files that is needed
% for actual wind. The output from this function is the
% the increase added resistance from waves as a percentage of
% the calm water resistance, a matrix including the wind
% resistance coefficient depended on wind heading, a matrix
% including the calm water resistance for a given velocity
% and the open water diagram used in prolusion calculations.
%
%------------------------------------------------------------
%   Variable name               Definition
%----------------------Input----------------------------------
%   NOHEAD                      Number of different headings in 
%                               Avspeed
%   NOTpHs                      Number of Tp and Hs in Avspeed
%   ADDEDRESinput               Speed loss input file from ShipX 
%                               (seaway_ship.out)
%   Cwindinput                  Wind resistance coefficient input 
%                               file
%   CalmResinput                Calm water resistance input file
%   OpenWaterinput              Open water diagram, text file
%-----------------------Output-----------------------------
%   AddedRes                    Matrix with increased resistance 
%                               due to waves
%   C_wind                      Matrix with wind drag coefficient 
%                               for different headings
%   R_calm                      Calm water resistance matrix
%   OpenWater                   Matrix with open water values
%-----------------------Internal-----------------------------
%   LengthCwind                 Number of rows in windres 
%                               coefficient file
%   LengthCalm                  Number of rows in calm water
%                               resistance file
%   M                           Variable including all columns in
%                               input file
%   j                           Counting integer 
%   i                           Counting integer
 
 
 
function [AddedRes,C_wind,R_calm,OpenWater]=increaseaddedres...
    (NOHEAD,NOTpHs,ADDEDRESinput,Cwindinput,CalmResinput,...
     OpenWaterinput)
 
Cwind=fopen(Cwindinput,'r');
Calm=fopen(CalmResinput,'r');
Added=fopen(ADDEDRESinput,'r');
OpenW=fopen(OpenWaterinput,'r');
 
LengthCwind = numel(textread(Cwindinput,'%1c%*[^\n]'));
LengthCalm = numel(textread(CalmResinput,'%1c%*[^\n]'));
 
 
%Writing matrix for wind resistance coefficient
for i=1:LengthCwind
    %enters heading into first column of wind coefficient 
    %matrix
    C_wind(i,1)=fscanf(Cwind,'%f',1);
    %enters coefficient into second column of wind 
    %coefficient matrix
    C_wind(i,2)=fscanf(Cwind,'%f',1);
end
 
%Writing matrix for calm water resistance
for i=1:LengthCalm
    %enters velocity into first column of the calm 
    %resistance matrix
    R_calm(i,1)=fscanf(Calm,'%f',1);
    %enters resistance into second column of the 
    %calm resistance matrix
    R_calm(i,2)=fscanf(Calm,'%f',1);
end
 
 
%Writing matrix for added resistance in waves
for i=1:NOHEAD
    char=fscanf(Added,'%c',[1,35]);
    head=fscanf(Added,'%f',1);
    char2=fscanf(Added,'%c',[1,300]);
    
    for j=1:NOTpHs
        M=fscanf(Added,'%f %f %f %f %f %f %f %f %f %f %f %f',[1,12]);
        %Defining heading as the first column
        AddedRes((i-1)*NOTpHs+j,1)=head;
        %Defining Hs as the second column
        AddedRes((i-1)*NOTpHs+j,2)=M(1);
        %Defining peak period as the third column
        AddedRes((i-1)*NOTpHs+j,3)=M(2);
        %Defining percentage resistance increase due to waves 
        %as the fourth column
        AddedRes((i-1)*NOTpHs+j,4)=M(6);
    end
end
lengthOpenW=fscanf(OpenW,'%f',1);
for i=1:lengthOpenW
   M=fscanf(OpenW,'%f %f %f %f %f',[1,5]);
   %Writing J values into the first column
   OpenWater(i,1)=M(1);
   %Writing K_Q into the second column
   OpenWater(i,2)=M(2)/10;
   %Writing K_T into the third column
   OpenWater(i,3)=M(3);
   %Writing eta_0 into the fourth column
   OpenWater(i,4)=M(3)/(M(2)/10)*M(1)/(2*pi());
   %Writing Kt/j^2 into the fifth column
   OpenWater(i,5)=M(3)/M(1)^2;
end
 
end


