%------------------------------------------------------------
%               speedloss.m
%               Hege Eskild
%               Spring 2014
%
% This functions reads the attainable speed from the ShipX
% speed loss file (seaway_ship). Writing out a matrix with the 
% attainable speed for different sea states. Also gives out 
% number of headings in the input file, and total number of
% Hs and Tp, to be used in increaseaddedres.m
%
%------------------------------------------------------------
%   Variable name               Definition
%------------------- Input-------------------------------------
%   SLinput                     Speed loss input file from ShipX 
%                               deduction
%--------------------Output------------------------------------
%   AVspeed                     Matrix with attainable speed for 
%                               different sea states
%   NOHEAD                      Number of different headings in 
%                               Avspeed
%   NOTpHs                      Number of Tp and Hs in Avspeed
%-------------------Internal--------------------------------
%   HEAD                        Heading from input file
%   M                           Matrix including all columns in 
%                               the input file
%   j                           Counting integer 
%   i                           Counting integer
 
 
function [AVspeed,NOHEAD,NOTpHs]=speedloss(SLinput)
 
%reading number of headings, as well as number of Hs And Tp
NOHEAD=fscanf(SLinput,'%f',1);
NOTpHs=fscanf(SLinput,'%f',1);
 
%Creating an attainable speed matrix
AVspeed=zeros(NOTpHs*NOHEAD,4);
 
for j=1:NOHEAD
 
HEAD=fscanf(SLinput,'%f',1);
 
for i=1:NOTpHs
    M=fscanf(SLinput, '%f %f %f %f %f %f %f %f %f %f %f %f', [1,12]);
    %Writing heading into the first column in the attainable 
    %speed matrix
    AVspeed((j-1)*NOTpHs+i,1)=HEAD;
    %Writing Hs into the second column in the attainable 
    %speed matrix
    AVspeed((j-1)*NOTpHs+i,2)=M(:,1);
    %Writing Tp into the third column in the attainable 
    %speed matrix
    AVspeed((j-1)*NOTpHs+i,3)=M(:,2);
    %Writing attainable speed into the fourth column of matrix
    AVspeed((j-1)*NOTpHs+i,4)=M(:,7);
end
 
end
 
AVspeed;
 
 
end
 


